/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.latitude.model;

import com.google.api.client.json.GenericJson;

/**
 * A Location resource identifies a user's position at a particular time. It may include metadata
 * about the user's position, such as a venue if the location was recorded at the time of a check-
 * in.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Latitude API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Location extends GenericJson {

  /**
   * Accuracy of the latitude and longitude coordinates, in non-negative meters. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object accuracy;

  /**
   * Unique ID of the Buzz message that corresponds to the check-in associated with this location.
   * Available only for check-in locations. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object activityId;

  /**
   * Altitude of the location, in meters. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object altitude;

  /**
   * Accuracy of the altitude value, in meters. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object altitudeAccuracy;

  /**
   * Direction of travel of the user when this location was recorded. In degrees, clockwise relative
   * to true north. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object heading;

  /**
   * Kind of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Latitude of the location, in decimal degrees.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object latitude;

  /**
   * Longitude of the location, in decimal degrees.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object longitude;

  /**
   * Ground speed of the user at the time this location was recorded, in meters per second. Non-
   * negative. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object speed;

  /**
   * Timestamp of the Location Resource, in milliseconds since the epoch (UTC). This is also the
   * Location Resource's unique id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Object timestampMs;

  /**
   * Accuracy of the latitude and longitude coordinates, in non-negative meters. Optional.
   * The value returned may be {@code null}.
   */
  public Object getAccuracy() {
    return accuracy;
  }

  /**
   * Accuracy of the latitude and longitude coordinates, in non-negative meters. Optional.
   * The value set may be {@code null}.
   */
  public Location setAccuracy(Object accuracy) {
    this.accuracy = accuracy;
    return this;
  }

  /**
   * Unique ID of the Buzz message that corresponds to the check-in associated with this location.
   * Available only for check-in locations. Optional.
   * The value returned may be {@code null}.
   */
  public Object getActivityId() {
    return activityId;
  }

  /**
   * Unique ID of the Buzz message that corresponds to the check-in associated with this location.
   * Available only for check-in locations. Optional.
   * The value set may be {@code null}.
   */
  public Location setActivityId(Object activityId) {
    this.activityId = activityId;
    return this;
  }

  /**
   * Altitude of the location, in meters. Optional.
   * The value returned may be {@code null}.
   */
  public Object getAltitude() {
    return altitude;
  }

  /**
   * Altitude of the location, in meters. Optional.
   * The value set may be {@code null}.
   */
  public Location setAltitude(Object altitude) {
    this.altitude = altitude;
    return this;
  }

  /**
   * Accuracy of the altitude value, in meters. Optional.
   * The value returned may be {@code null}.
   */
  public Object getAltitudeAccuracy() {
    return altitudeAccuracy;
  }

  /**
   * Accuracy of the altitude value, in meters. Optional.
   * The value set may be {@code null}.
   */
  public Location setAltitudeAccuracy(Object altitudeAccuracy) {
    this.altitudeAccuracy = altitudeAccuracy;
    return this;
  }

  /**
   * Direction of travel of the user when this location was recorded. In degrees, clockwise relative
   * to true north. Optional.
   * The value returned may be {@code null}.
   */
  public Object getHeading() {
    return heading;
  }

  /**
   * Direction of travel of the user when this location was recorded. In degrees, clockwise relative
   * to true north. Optional.
   * The value set may be {@code null}.
   */
  public Location setHeading(Object heading) {
    this.heading = heading;
    return this;
  }

  /**
   * Kind of this item.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of this item.
   * The value set may be {@code null}.
   */
  public Location setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Latitude of the location, in decimal degrees.
   * The value returned may be {@code null}.
   */
  public Object getLatitude() {
    return latitude;
  }

  /**
   * Latitude of the location, in decimal degrees.
   * The value set may be {@code null}.
   */
  public Location setLatitude(Object latitude) {
    this.latitude = latitude;
    return this;
  }

  /**
   * Longitude of the location, in decimal degrees.
   * The value returned may be {@code null}.
   */
  public Object getLongitude() {
    return longitude;
  }

  /**
   * Longitude of the location, in decimal degrees.
   * The value set may be {@code null}.
   */
  public Location setLongitude(Object longitude) {
    this.longitude = longitude;
    return this;
  }

  /**
   * Ground speed of the user at the time this location was recorded, in meters per second. Non-
   * negative. Optional.
   * The value returned may be {@code null}.
   */
  public Object getSpeed() {
    return speed;
  }

  /**
   * Ground speed of the user at the time this location was recorded, in meters per second. Non-
   * negative. Optional.
   * The value set may be {@code null}.
   */
  public Location setSpeed(Object speed) {
    this.speed = speed;
    return this;
  }

  /**
   * Timestamp of the Location Resource, in milliseconds since the epoch (UTC). This is also the
   * Location Resource's unique id.
   * The value returned may be {@code null}.
   */
  public Object getTimestampMs() {
    return timestampMs;
  }

  /**
   * Timestamp of the Location Resource, in milliseconds since the epoch (UTC). This is also the
   * Location Resource's unique id.
   * The value set may be {@code null}.
   */
  public Location setTimestampMs(Object timestampMs) {
    this.timestampMs = timestampMs;
    return this;
  }

}
